@@ -7,15 +7,19 @@
 package org.mule.module.launcher;
 
 import static com.google.common.base.Optional.absent;
+import static java.lang.Boolean.valueOf;
 import static org.apache.commons.lang.StringUtils.removeEndIgnoreCase;
 import static org.mule.module.launcher.DeploymentPropertiesUtils.resolveDeploymentProperties;
 import static org.mule.util.SplashScreen.miniSplash;
 
 import org.mule.config.i18n.CoreMessages;
 import org.mule.config.i18n.MessageFactory;
+import org.mule.module.launcher.application.Application;
+import org.mule.module.launcher.application.ApplicationStatus;
 import org.mule.module.launcher.application.NullDeploymentListener;
 import org.mule.module.launcher.artifact.Artifact;
 import org.mule.module.launcher.artifact.ArtifactFactory;
+import org.mule.module.launcher.domain.Domain;
 import org.mule.module.launcher.util.ObservableList;
 import org.mule.util.CollectionUtils;
 
@@ -46,6 +50,7 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
     public static final String ARTIFACT_NAME_PROPERTY = "artifactName";
     public static final String ZIP_FILE_SUFFIX = ".zip";
     private static final Log logger = LogFactory.getLog(DefaultArchiveDeployer.class);
+    static final String START_ARTIFACT_ON_DEPLOYMENT_PROPERTY = "startArtifactOnDeployment";
 
     private final ArtifactDeployer<T> deployer;
     private final ArtifactArchiveInstaller artifactArchiveInstaller;
@@ -55,9 +60,10 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
     private final ArtifactDeploymentTemplate deploymentTemplate;
     private ArtifactFactory<T> artifactFactory;
     private DeploymentListener deploymentListener = new NullDeploymentListener();
+    private final DeploymentService deploymentService;
 
     public DefaultArchiveDeployer(final ArtifactDeployer deployer, final ArtifactFactory artifactFactory, final ObservableList<T> artifacts,
-                                  ArtifactDeploymentTemplate deploymentTemplate)
+                                  ArtifactDeploymentTemplate deploymentTemplate, DeploymentService deploymentService)
     {
         this.deployer = deployer;
         this.artifactFactory = artifactFactory;
@@ -65,6 +71,7 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
         this.deploymentTemplate = deploymentTemplate;
         this.artifactDir = artifactFactory.getArtifactDir();
         this.artifactArchiveInstaller = new ArtifactArchiveInstaller(artifactDir);
+        this.deploymentService = deploymentService;
     }
 
     @Override
@@ -96,8 +103,19 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
         {
             return null;
         }
+        Optional<Properties> properties = absent();
+        return deployExplodedApp(artifactDir, properties);
+    }
 
-        return deployExplodedApp(artifactDir);
+    @Override
+    public T deployExplodedArtifact(String artifactDir, Optional<Properties> properties) throws DeploymentException
+    {
+        if (!isUpdatedZombieArtifact(artifactDir))
+        {
+            return null;
+        }
+
+        return deployExplodedApp(artifactDir, properties);
     }
 
     @Override
@@ -123,17 +141,9 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
     @Override
     public void undeployArtifact(String artifactId)
     {
-        ZombieFile zombieFile = artifactZombieMap.get(artifactId);
-
-        if ((zombieFile != null))
+        if (isZombieArtifact(artifactId))
         {
-            if (zombieFile.exists()) {
-                return;
-            }
-            else
-            {
-                artifactZombieMap.remove(artifactId);
-            }
+            return;
         }
 
         T artifact = (T) CollectionUtils.find(artifacts, new BeanPropertyValueEqualsPredicate(ARTIFACT_NAME_PROPERTY, artifactId));
@@ -205,7 +215,7 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
             throw new DeploymentException(MessageFactory.createStaticMessage(msg), t);
         }
     }
-  
+
     private void logDeploymentFailure(Throwable t, String artifactName)
     {
         final String msg = miniSplash(String.format("Failed to deploy artifact '%s', see below", artifactName));
@@ -273,18 +283,32 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
 
         // check if this artifact is running first, undeployArtifact it then
         T artifact = (T) CollectionUtils.find(artifacts, new BeanPropertyValueEqualsPredicate(ARTIFACT_NAME_PROPERTY, artifactName));
+        Map<Application, ApplicationStatus> appStatusPreRedeployment = new HashMap<>();
         if (artifact != null)
         {
+            if (artifact instanceof Domain){
+                Collection<Application> domainApplications = findApplicationsAssociated((Domain) artifact);
+                for (Application domainApplication : domainApplications)
+                {
+                    appStatusPreRedeployment.put(domainApplication, domainApplication.getStatus());
+                }
+            }
             deploymentTemplate.preRedeploy(artifact);
             undeployArtifact(artifactName);
         }
 
         T deployedAtifact = deployPackagedArtifact(artifactUrl, deploymentProperties);
-        deploymentTemplate.postRedeploy(deployedAtifact);
+        deploymentTemplate.postRedeploy(deployedAtifact, appStatusPreRedeployment);
         return deployedAtifact;
     }
 
-    private T deployExplodedApp(String addedApp) throws DeploymentException
+
+    private Collection<Application> findApplicationsAssociated(Domain domain)
+    {
+        return deploymentService.findDomainApplications(domain.getArtifactName());
+    }
+
+    private T deployExplodedApp(String addedApp, Optional<Properties> properties) throws DeploymentException
     {
         if (logger.isInfoEnabled())
         {
@@ -322,7 +346,7 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
             }
         }
 
-        deployArtifact(artifact);
+        deployArtifact(artifact, properties);
         return artifact;
     }
 
@@ -524,6 +548,25 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
         artifactZombieMap.remove(artifact.getArtifactName());
     }
 
+    public boolean isZombieArtifact(String artifactId)
+    {
+        ZombieFile zombieFile = artifactZombieMap.get(artifactId);
+
+        if ((zombieFile != null))
+        {
+            if (zombieFile.exists())
+            {
+                return true;
+            }
+            else
+            {
+                artifactZombieMap.remove(artifactId);
+                return false;
+            }
+        }
+        return false;
+    }
+
     @Override
     public void deployArtifact(T artifact, Optional<Properties> deploymentProperties) throws DeploymentException
     {
@@ -533,7 +576,7 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
             trackArtifact(artifact);
 
             deploymentListener.onDeploymentStart(artifact.getArtifactName());
-            deployer.deploy(artifact);
+            deployer.deploy(artifact, shouldStartArtifact(artifact, deploymentProperties.orNull()));
             artifactArchiveInstaller.createAnchorFile(artifact.getArtifactName());
             deploymentListener.onDeploymentSuccess(artifact.getArtifactName());
             artifactZombieMap.remove(artifact.getArtifactName());
@@ -559,6 +602,16 @@ public class DefaultArchiveDeployer<T extends Artifact> implements ArchiveDeploy
         }
     }
 
+    private boolean shouldStartArtifact(T artifact, Properties deploymentProperties)
+    {
+        if (!(artifact instanceof Application) || deploymentProperties == null)
+        {
+            return true;
+        }
+
+        return valueOf(deploymentProperties.getProperty(START_ARTIFACT_ON_DEPLOYMENT_PROPERTY, "true"));
+    }
+
     @Override
     public T deployPackagedArtifact(String zip) throws DeploymentException
     {
