@@ -32,6 +32,7 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Map;
 import java.util.concurrent.RejectedExecutionException;
 
 import javax.resource.spi.work.Work;
@@ -105,10 +106,10 @@ public class VMMessageReceiver extends TransactedPollingMessageReceiver
     protected void pollMessagesOutsideTransactions() throws Exception
     {
         ExecutionTemplate<MuleEvent> pt = createExecutionTemplate();
-        List messages = getMessages();
+        List<MuleMessage> messages = getMessages();
         if (messages != null && messages.size() > 0)
         {
-            for (Object message : messages)
+            for (MuleMessage message : messages)
             {
                 try
                 {
@@ -294,7 +295,7 @@ public class VMMessageReceiver extends TransactedPollingMessageReceiver
                 message = getMessage(queue, 0);
                 if (message != null)
                 {
-                    messages.add(new DefaultMuleMessage(message, endpoint.getMuleContext()));
+                    messages.add(new DefaultMuleMessage(message, null, (Map<String, Object>) null, null, endpoint.getMuleContext(), message.getDataType()));
                 }
             }
         }
